| GaoPC | R Documentation |
This function estimates the load and residual terms based on the general factor model and calculates the estimated values.
GaoPC(data,m)
data |
The data is total data set |
m |
The m is the number of principal component |
AG1 |
estimation of load value |
AG2 |
estimation of load value |
DG1 |
estimation of error term |
DG2 |
estimation of error term |
SigmahatG1 |
estimation of covariance |
SigmahatG2 |
estimation of covariance |
Guangbao Guo, Yaping Li
GaoPC(data=ISE,m=3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.